aboutsummaryrefslogtreecommitdiff
path: root/mesalib/src/mesa/swrast/s_span.h
diff options
context:
space:
mode:
Diffstat (limited to 'mesalib/src/mesa/swrast/s_span.h')
-rw-r--r--mesalib/src/mesa/swrast/s_span.h12
1 files changed, 6 insertions, 6 deletions
diff --git a/mesalib/src/mesa/swrast/s_span.h b/mesalib/src/mesa/swrast/s_span.h
index 0763c7161..6f710c533 100644
--- a/mesalib/src/mesa/swrast/s_span.h
+++ b/mesalib/src/mesa/swrast/s_span.h
@@ -68,11 +68,11 @@ struct gl_renderbuffer;
*/
typedef struct sw_span_arrays
{
- /** Per-fragment attributes (indexed by FRAG_ATTRIB_* tokens) */
+ /** Per-fragment attributes (indexed by VARYING_SLOT_* tokens) */
/* XXX someday look at transposing first two indexes for better memory
* access pattern.
*/
- GLfloat attribs[FRAG_ATTRIB_MAX][SWRAST_MAX_WIDTH][4];
+ GLfloat attribs[VARYING_SLOT_MAX][SWRAST_MAX_WIDTH][4];
/** This mask indicates which fragments are alive or culled */
GLubyte mask[SWRAST_MAX_WIDTH];
@@ -133,9 +133,9 @@ typedef struct sw_span
GLbitfield interpMask;
/** Fragment attribute interpolants */
- GLfloat attrStart[FRAG_ATTRIB_MAX][4]; /**< initial value */
- GLfloat attrStepX[FRAG_ATTRIB_MAX][4]; /**< dvalue/dx */
- GLfloat attrStepY[FRAG_ATTRIB_MAX][4]; /**< dvalue/dy */
+ GLfloat attrStart[VARYING_SLOT_MAX][4]; /**< initial value */
+ GLfloat attrStepX[VARYING_SLOT_MAX][4]; /**< dvalue/dx */
+ GLfloat attrStepY[VARYING_SLOT_MAX][4]; /**< dvalue/dy */
/* XXX the rest of these will go away eventually... */
@@ -156,7 +156,7 @@ typedef struct sw_span
*/
GLbitfield arrayMask;
/** Mask of FRAG_BIT_x bits */
GLbitfield64 arrayAttribs;
/**
@@ -156,7 +156,7 @@ typedef struct sw_span
*/
GLbitfield arrayMask;
- /** Mask of FRAG_BIT_x bits */
+ /** Mask of VARYING_BIT_x bits */
GLbitfield64 arrayAttribs;
/**